OQS_SIG_supports_ctx_str

Function OQS_SIG_supports_ctx_str 

pub unsafe extern "C" fn OQS_SIG_supports_ctx_str(
    alg_name: *const c_char,
) -> bool
Indicates whether the specified signature algorithm supports signing with a context string.

@param[in] alg_name Name of the desired algorithm; one of the names in OQS_SIG_algs. @return true if the algorithm supports context string signing, false otherwise.